#
# s10664-fishing.R, 27 Aug 23
#
# Data from:
# Two N-of-1 self-trials on readability differences between anonymous inner classes (AICs) and lambda expressions (LEs) on Java code snippets
# Stefan Hanenberg and Nils Mehlhorn

library("colorspace")
library("lme4")
library("plyr")
library("reshape2")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(4)


t1d=read.csv("Test1_Data.csv", as.is=TRUE)
t2d=read.csv("Test2_Data.csv", as.is=TRUE)

plot(t1d$S1_Time)

plot(~ S1_Time+sqrt(length)+unusedParams+log(Snippet+1), data=t1d)

table(t1d$params, t1d$usedParams)
#    
#       0   1   2   3   4
#   0 120   0   0   0   0
#   1  66  54   0   0   0
#   2  47  54  19   0   0
#   3  45  44  22   9   0
#   4  34  50  26   8   2
table(t1d$unusedParams, t1d$usedParams)
#    
#       0   1   2   3   4
#   0 120  54  19   9   2
#   1  66  54  22   8   0
#   2  47  44  26   0   0
#   3  45  50   0   0   0
#   4  34   0   0   0   0
table(t1d$CodeType, t1d$numDeclarations)
#                 
#                   1  2  3  4  5  6
#   AIC            20 68 61 36 14  1
#   LEwithoutTypes 24 60 63 42 11  0
#   LEwithTypes    15 68 65 41  9  2
table(t1d$CodeType, t1d$listenerBodyLOC)
#                 
#                   1  2  3  4  5  6
#   AIC            32 60 51 40 15  2
#   LEwithoutTypes 37 49 61 42  9  2
#   LEwithTypes    35 53 62 36 12  2
table(t1d$numDeclarations, t1d$listenerBodyLOC)
#    
#      1  2  3  4  5  6
#   1  9 15 16 15  3  1
#   2 35 52 55 41 11  2
#   3 36 53 53 33 13  1
#   4 17 33 39 22  6  2
#   5  7  7 10  7  3  0
#   6  0  2  1  0  0  0

plot(t1d$length, t1d$LOCcorrected)

# log(Snippet+1) is the learning factor, assuming the exponential model of learning
s1t_mod=glm(S1_Time ~ log(length)+params+CodeType+log(Snippet+1), data=t1d)
summary(s1t_mod)

# Remove outliers???
s1t_mod=glm(S1_Time ~ log(length)+params+CodeType+log(Snippet+1), data=t1d,
							subset=(S1_Time > 200) & (S1_Time < 4000))
summary(s1t_mod)

# Melt subject times to a single column
mt1=melt(t1d, measure.vars=c("S1_Time", "S2_Time", "S3_Time", "S4_Time",
				"S5_Time", "S6_Time", "S7_Time", "S8_Time"),
		variable.name="Subject", value.name="Time")

ma1=melt(t1d, measure.vars=c("S1_Correct", "S2_Correct", "S3_Correct", "S4_Correct",
				"S5_Correct", "S6_Correct", "S7_Correct", "S8_Correct"),
		variable.name="Subject", value.name="Correct")

plot(sort(mt1$Time))

mean(mt1$Time)
# [1] 1521.759

range(mt1$Time)
# [1]  392 8398

# Build a random/mixed effects model
# mt1_mod=lmer(Time ~ log(length)+params*CodeType+log(Snippet+1)+(1+CodeType | Subject), data=mt1)
mt1_mod=lmer(Time ~ log(length)+params+CodeType+log(Snippet+1)+(1+CodeType | Subject), data=mt1)
summary(mt1_mod)

mt1_mod=lmer(Time ~ log(length)+params+CodeType+log(Snippet+1)+(1+CodeType | Subject), data=mt1,
								subset=(Time > 200) & (Time < 4000))
summary(mt1_mod)


# Model that just includes when correct answers given
ma1_mod=lmer(Time ~ log(length)+params+CodeType+log(Snippet+1)+(CodeType+params-1 | Subject), data=mt1)
summary(ma1_mod)

# Build a multiplicative model
mt1L_mod=lmer(log(Time) ~ log(length)+log(params+1)+CodeType+log(Snippet+1)+(CodeType+params-1 | Subject), data=mt1)
summary(mt1L_mod)

# Model answer accuracy
# sac_mod=glm(Correct ~ log(Time)+log(Snippet+1), data=lt1d, family=binomial)
sac_mod=glmer(Correct ~ unusedParams+log(Snippet+1)+(1 | Subject), data=lt1d, family=binomial)
summary(sac_mod)



# Task 2

# Try various ideas
s2t_mod=glm(S1_Time ~ log(length)+log(LOCcorrected)+numDeclarations+CodeType+log(Snippet+1), data=t2d)

s2t_mod=glm(S1_Time ~ log(length)+log(LOCcorrected)+usedParams+CodeType+log(Snippet+1), data=t2d)

summary(s2t_mod)

# Melt subject times to a single column
mt2=melt(t2d, measure.vars=c("S1_Time", "S2_Time", "S3_Time", "S4_Time",
				"S5_Time", "S6_Time", "S7_Time", "S8_Time"),
		variable.name="Subject", value.name="Time")

ma2=melt(t2d, measure.vars=c("S1_Correct", "S2_Correct", "S3_Correct", "S4_Correct",
				"S5_Correct", "S6_Correct", "S7_Correct", "S8_Correct"),
		variable.name="Subject", value.name="Correct")

plot(sort(mt2$Time))

mean(mt2$Time)
# [1] 3724.08

range(mt2$Time)
# [1]  1191 14743

# Build a random/mixed effects model
# mt2_mod=lmer(Time ~ log(length)+usedParams*CodeType+log(Snippet+1)+(1+CodeType | Subject), data=mt2)
mt2_mod=lmer(Time ~ log(length)+log(LOCcorrected)+usedParams+CodeType+log(Snippet+1)+(CodeType+usedParams-1 | Subject), data=mt2)
summary(mt2_mod)

mt2_mod=lmer(Time ~ log(length)+log(LOCcorrected)+usedParams+CodeType+log(Snippet+1)+(CodeType+usedParams-1 | Subject), data=mt2,
								subset=(Time > 1800) & (Time < 8000))
summary(mt2_mod)


# Model that just includes when correct answers given
cma2_mod=lmer(Time ~ log(length)+usedParams+CodeType+log(Snippet+1)+(1+CodeType | Subject), data=cma2)
summary(ma2_mod)

# Build a multiplicative model
mt2L_mod=lmer(log(Time) ~ log(length)+log(usedParams+1)+CodeType+log(Snippet+1)+(1+CodeType | Subject), data=mt2)
summary(mt2L_mod)

# Model answer accuracy
# sac_mod=glm(Correct ~ log(Time)+log(Snippet+1), data=lt2d, family=binomial)
sac_mod=glmer(Correct ~ unusedParams+log(Snippet+1)+(1 | Subject), data=lt2d, family=binomial)
summary(sac_mod)



